@@ -103,7 +103,7 @@ class AsyncBaseClientOpenTelemetry:
             yield message
 
     async def _execute(self, query: str, operation_name: Optional[str]=None, variables: Optional[Dict[str, Any]]=None, **kwargs: Any) -> httpx.Response:
-        (processed_variables, files, files_map) = self._process_variables(variables)
+        processed_variables, files, files_map = self._process_variables(variables)
         if files and files_map:
             return await self._execute_multipart(query=query, operation_name=operation_name, variables=processed_variables, files=files, files_map=files_map, **kwargs)
         return await self._execute_json(query=query, operation_name=operation_name, variables=processed_variables, **kwargs)
@@ -115,7 +115,7 @@ class AsyncBaseClientOpenTelemetry:
         return self._get_files_from_variables(serializable_variables)
 
     def _convert_dict_to_json_serializable(self, dict_: Dict[str, Any]) -> Dict[str, Any]:
-        return {key: self._convert_value(value) for (key, value) in dict_.items() if value is not UNSET}
+        return {key: self._convert_value(value) for key, value in dict_.items() if value is not UNSET}
 
     def _convert_value(self, value: Any) -> Any:
         if isinstance(value, BaseModel):
@@ -131,13 +131,13 @@ class AsyncBaseClientOpenTelemetry:
         def separate_files(path: str, obj: Any) -> Any:
             if isinstance(obj, list):
                 nulled_list = []
-                for (index, value) in enumerate(obj):
+                for index, value in enumerate(obj):
                     value = separate_files(f'{path}.{index}', value)
                     nulled_list.append(value)
                 return nulled_list
             if isinstance(obj, dict):
                 nulled_dict = {}
-                for (key, value) in obj.items():
+                for key, value in obj.items():
                     value = separate_files(f'{path}.{key}', value)
                     nulled_dict[key] = value
                 return nulled_dict
@@ -152,7 +152,7 @@ class AsyncBaseClientOpenTelemetry:
                 return None
             return obj
         nulled_variables = separate_files('variables', variables)
-        files: Dict[str, Tuple[str, IO[bytes], str]] = {str(i): (file_.filename, cast(IO[bytes], file_.content), file_.content_type) for (i, file_) in enumerate(files_list)}
+        files: Dict[str, Tuple[str, IO[bytes], str]] = {str(i): (file_.filename, cast(IO[bytes], file_.content), file_.content_type) for i, file_ in enumerate(files_list)}
         return (nulled_variables, files, files_map)
 
     async def _execute_multipart(self, query: str, operation_name: Optional[str], variables: Dict[str, Any], files: Dict[str, Tuple[str, IO[bytes], str]], files_map: Dict[str, List[str]], **kwargs: Any) -> httpx.Response:
@@ -220,7 +220,7 @@ class AsyncBaseClientOpenTelemetry:
     async def _execute_with_telemetry(self, query: str, operation_name: Optional[str]=None, variables: Optional[Dict[str, Any]]=None, **kwargs: Any) -> httpx.Response:
         with self.tracer.start_as_current_span(self.root_span_name, context=self.root_context) as root_span:
             root_span.set_attribute('component', 'GraphQL Client')
-            (processed_variables, files, files_map) = self._process_variables(variables)
+            processed_variables, files, files_map = self._process_variables(variables)
             if files and files_map:
                 return await self._execute_multipart_with_telemetry(root_span=root_span, query=query, operation_name=operation_name, variables=processed_variables, files=files, files_map=files_map, **kwargs)
             return await self._execute_json_with_telemetry(root_span=root_span, query=query, operation_name=operation_name, variables=processed_variables, **kwargs)
