@@ -81,6 +81,13 @@ class BillingUsageGraphQLField(GraphQLField):
         self._alias = alias
         return self
 
+class BufferInfoGraphQLField(GraphQLField):
+    """@private"""
+
+    def alias(self, alias: str) -> 'BufferInfoGraphQLField':
+        self._alias = alias
+        return self
+
 class ChatMessageGraphQLField(GraphQLField):
     """@private"""
 
@@ -221,6 +228,20 @@ class DatasetMetricUsageGraphQLField(GraphQLField):
         self._alias = alias
         return self
 
+class DatasetProgressGraphQLField(GraphQLField):
+    """@private"""
+
+    def alias(self, alias: str) -> 'DatasetProgressGraphQLField':
+        self._alias = alias
+        return self
+
+class DatasetUploadProcessingStatusGraphQLField(GraphQLField):
+    """@private"""
+
+    def alias(self, alias: str) -> 'DatasetUploadProcessingStatusGraphQLField':
+        self._alias = alias
+        return self
+
 class DatasetValidationOutputGraphQLField(GraphQLField):
     """@private"""
 
@@ -309,6 +330,31 @@ class HarmonyGroupGraphQLField(GraphQLField):
         self._alias = alias
         return self
 
+class HarmonyGroupMetricEventUnion(GraphQLField):
+    """@private"""
+
+    def on(self, type_name: str, *subfields: GraphQLField) -> 'HarmonyGroupMetricEventUnion':
+        self._inline_fragments[type_name] = subfields
+        return self
+
+    def alias(self, alias: str) -> 'HarmonyGroupMetricEventUnion':
+        self._alias = alias
+        return self
+
+class HarmonyMemoryUsageGraphQLField(GraphQLField):
+    """@private"""
+
+    def alias(self, alias: str) -> 'HarmonyMemoryUsageGraphQLField':
+        self._alias = alias
+        return self
+
+class HarmonyMidMetricsGraphQLField(GraphQLField):
+    """@private"""
+
+    def alias(self, alias: str) -> 'HarmonyMidMetricsGraphQLField':
+        self._alias = alias
+        return self
+
 class InteractionOutputGraphQLField(GraphQLField):
     """@private"""
 
@@ -590,6 +636,13 @@ class ShareGraphQLField(GraphQLField):
         self._alias = alias
         return self
 
+class SubscriptionRootGraphQLField(GraphQLField):
+    """@private"""
+
+    def alias(self, alias: str) -> 'SubscriptionRootGraphQLField':
+        self._alias = alias
+        return self
+
 class SystemPromptTemplateGraphQLField(GraphQLField):
     """@private"""
 
