@@ -1,7 +1,7 @@
 from typing import Annotated, Any, List, Literal, Optional, Union
 from pydantic import Field
 from .base_model import BaseModel
-from .enums import AbcampaignStatus, CompletionSource, DatasetKind, FeedbackType, GraderTypeEnum, HarmonyStatus, JobArtifactKind, JobKind, JobStatus, JobStatusOutput, JudgeCapability, MetricKind, MetricScoringType, ModelKindFilter, ModelOnline, PrebuiltCriteriaKey, ProviderName, RemoteEnvStatus
+from .enums import AbcampaignStatus, CompletionSource, DatasetKind, FeedbackType, GraderTypeEnum, HarmonyStatus, JobArtifactKind, JobKind, JobStatus, JobStatusOutput, JudgeCapability, MetricKind, MetricScoringType, ModelOnline, PrebuiltCriteriaKey, ProviderName, RemoteEnvStatus
 
 class AbCampaignCreateData(BaseModel):
     """@public"""
@@ -245,7 +245,6 @@ class ModelData(BaseModel):
     is_adapter: bool = Field(alias='isAdapter')
     is_training: bool = Field(alias='isTraining')
     created_at: int = Field(alias='createdAt')
-    kind: ModelKindFilter
     size: Optional[str]
     compute_config: Optional['ModelDataComputeConfig'] = Field(alias='computeConfig')
 
@@ -535,7 +534,6 @@ class ModelDataAdmin(BaseModel):
     is_adapter: bool = Field(alias='isAdapter')
     is_training: bool = Field(alias='isTraining')
     created_at: int = Field(alias='createdAt')
-    kind: ModelKindFilter
     size: Optional[str]
 
 class ModelDataAdminUseCases(BaseModel):
