@@ -1,7 +1,7 @@
 from typing import Any, List, Optional
 from pydantic import Field
 from .base_model import BaseModel
-from .enums import AbcampaignStatus, CompletionGroupBy, CompletionSource, DatasetKind, DatasetSource, DateBucketUnit, ExternalModelProviderName, FeedbackType, GraderTypeEnum, JobArtifactKind, JobKind, JobStatus, MetricAggregation, MetricKind, MetricScoringType, ModelKindFilter, ModelOnline, OpenAIModel, PrebuiltCriteriaKey, Protocol, SelectionTypeInput, SortDirection, TimeseriesInterval, UnitPosition
+from .enums import AbcampaignStatus, CompletionGroupBy, CompletionSource, DatasetKind, DatasetSource, DateBucketUnit, ExternalModelProviderName, FeedbackType, GraderTypeEnum, JobArtifactKind, JobKind, JobStatus, MetricAggregation, MetricKind, MetricScoringType, ModelCapabilityFilter, ModelOnline, OpenAIModel, PrebuiltCriteriaKey, Protocol, SelectionTypeInput, SortDirection, TimeseriesInterval, UnitPosition
 
 class AbCampaignFilter(BaseModel):
     """@private"""
@@ -63,6 +63,7 @@ class AttachModel(BaseModel):
     attached: bool = True
     placement: Optional['ModelPlacementInput'] = None
     wait: bool = False
+    'Wait for the model to be deployed or not'
 
 class AzureProviderDataInput(BaseModel):
     """@private"""
@@ -70,6 +71,16 @@ class AzureProviderDataInput(BaseModel):
     external_model_id: str = Field(alias='externalModelId')
     endpoint: str
 
+class CancelAllocationInput(BaseModel):
+    """@private"""
+    harmony_group: str = Field(alias='harmonyGroup')
+    job_id: str = Field(alias='jobId')
+
+class CapabilityFilter(BaseModel):
+    """@private"""
+    any: Optional[List[ModelCapabilityFilter]] = None
+    all: Optional[List[ModelCapabilityFilter]] = None
+
 class CompletionComparisonFilterInput(BaseModel):
     """@private"""
     metric: str
@@ -153,6 +164,19 @@ class DatasetCreateFromFilters(BaseModel):
     kind: DatasetKind
     metrics: Optional[List[str]] = None
 
+class DatasetCreateFromMultipartUpload(BaseModel):
+    """@private"""
+    use_case: str = Field(alias='useCase')
+    name: str
+    key: Optional[str] = None
+    source: Optional[DatasetSource] = None
+    upload_session_id: str = Field(alias='uploadSessionId')
+
+class DatasetUploadProcessingStatusInput(BaseModel):
+    """@private"""
+    use_case: str = Field(alias='useCase')
+    dataset_id: Any = Field(alias='datasetId')
+
 class EmojiInput(BaseModel):
     """@private"""
     native: str
@@ -182,6 +206,7 @@ class FromGroupsQuery(BaseModel):
 class GlobalUsageFilterInput(BaseModel):
     """@private"""
     timerange: Optional['TimeRange'] = None
+    'use none to get "all time" data'
     interval: DateBucketUnit
     timezone: Optional[str] = None
 
@@ -247,7 +272,7 @@ class JudgeCreate(BaseModel):
     key: Optional[str] = None
     name: str
     criteria: str
-    examples: List['JudgeExampleInput'] = Field(default_factory=lambda : [])
+    examples: List['JudgeExampleInput'] = Field(default_factory=lambda: [])
     model: str
     metric: Optional[str] = None
 
@@ -344,7 +369,7 @@ class ModelFilter(BaseModel):
     in_storage: Optional[bool] = Field(alias='inStorage', default=None)
     available: Optional[bool] = None
     trainable: Optional[bool] = None
-    kind: Optional[List[ModelKindFilter]] = None
+    capabilities: Optional['CapabilityFilter'] = None
     view_all: Optional[bool] = Field(alias='viewAll', default=None)
     online: Optional[List[ModelOnline]] = None
 
@@ -369,7 +394,7 @@ class ModelServiceDisconnect(BaseModel):
 class ModelServiceFilter(BaseModel):
     """@private"""
     model: Optional[str] = None
-    kind: Optional[List[ModelKindFilter]] = None
+    capabilities: Optional['CapabilityFilter'] = None
 
 class NvidiaProviderDataInput(BaseModel):
     """@private"""
@@ -475,9 +500,13 @@ class UpdateCompletion(BaseModel):
     """@private"""
     id: Any
     remove_labels: Optional[List['CompletionLabelValue']] = Field(alias='removeLabels', default=None)
+    'remove some label value. This operation is atomic'
     add_labels: Optional[List['CompletionLabelValue']] = Field(alias='addLabels', default=None)
+    'add a label value. This operation is atomic'
     set_labels: Optional[List['CompletionLabelValue']] = Field(alias='setLabels', default=None)
+    "set the completion labels to this list. If you want to only add or remove specific labels,\nit's better to use `add_labels` or `remove_labels`"
     metadata: Optional[Any] = None
+    'set metadata associated with this prompt for use with external reward servers'
 
 class UpdateModelService(BaseModel):
     """@private"""
@@ -595,7 +624,9 @@ ListCompletionsFilterInput.model_rebuild()
 ListJobsFilterInput.model_rebuild()
 MetricGetOrCreate.model_rebuild()
 MetricTrendInput.model_rebuild()
+ModelFilter.model_rebuild()
 ModelProviderDataInput.model_rebuild()
+ModelServiceFilter.model_rebuild()
 TimeseriesInput.model_rebuild()
 UpdateCompletion.model_rebuild()
 UpdateModelService.model_rebuild()
