@@ -2,10 +2,7 @@ from uuid import UUID
 from pydantic import BaseModel as PydanticBaseModel, ConfigDict
 
 class BaseModel(PydanticBaseModel):
-    """@public
-@public
-@public
-@private"""
+    """@public"""
     model_config = ConfigDict(populate_by_name=True, validate_assignment=True, arbitrary_types_allowed=True, protected_namespaces=())
 
     def model_dump(self, *args, **kwargs) -> dict:
